@@ -1,12 +1,14 @@
 import sympy as sy
 import IPython
 
-DatosList = []
-Orden = 8
+
 
 #Funciones de Redondeo
 
-def Actualizar():
+def Artemix():
+  global Orden,DatosList
+  DatosList = []
+  Orden = 8
 
   def Redondear(expr):#Redondeamos la expresión.
     if isinstance(expr, sy.Expr) or isinstance(expr, sy.Float):
